You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@pdfbox.apache.org by ti...@apache.org on 2016/11/25 16:46:32 UTC

svn commit: r1771343 - /pdfbox/trunk/pdfbox/src/main/java/org/apache/pdfbox/pdmodel/graphics/state/PDGraphicsState.java

Author: tilman
Date: Fri Nov 25 16:46:31 2016
New Revision: 1771343

URL: http://svn.apache.org/viewvc?rev=1771343&view=rev
Log:
PDFBOX-2852: deprecate methods that have a misleading name, add correct methods

Modified:
    pdfbox/trunk/pdfbox/src/main/java/org/apache/pdfbox/pdmodel/graphics/state/PDGraphicsState.java

Modified: pdfbox/trunk/pdfbox/src/main/java/org/apache/pdfbox/pdmodel/graphics/state/PDGraphicsState.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/pdfbox/src/main/java/org/apache/pdfbox/pdmodel/graphics/state/PDGraphicsState.java?rev=1771343&r1=1771342&r2=1771343&view=diff
==============================================================================
--- pdfbox/trunk/pdfbox/src/main/java/org/apache/pdfbox/pdmodel/graphics/state/PDGraphicsState.java (original)
+++ pdfbox/trunk/pdfbox/src/main/java/org/apache/pdfbox/pdmodel/graphics/state/PDGraphicsState.java Fri Nov 25 16:46:31 2016
@@ -200,9 +200,9 @@ public class PDGraphicsState implements
     }
 
     /**
      * Get the value of the stroke alpha constants property.
      *
      * @return The value of the stroke alpha constants parameter.
      */
     public double getAlphaConstant()
     {
@@ -210,9 +210,9 @@ public class PDGraphicsState implements
     }
 
     /**
      * set the value of the stroke alpha constants property.
      *
      * @param value The value of the stroke alpha constants parameter.
      */
     public void setAlphaConstant(double value)
     {
@@ -220,24 +220,48 @@ public class PDGraphicsState implements
     }
 
     /**
      * Get the value of the non-stroke alpha constants property.
      *
      * @return The value of the non-stroke alpha constants parameter.
      */
+    @Deprecated
     public double getNonStrokeAlphaConstants()
     {
         return nonStrokingAlphaConstant;
     }
 
     /**
      * set the value of the non-stroke alpha constants property.
      *
      * @param value The value of the non-stroke alpha constants parameter.
      */
+    @Deprecated
     public void setNonStrokeAlphaConstants(double value)
     {
         nonStrokingAlphaConstant = value;
     }
+
+    /**
+     * Get the value of the non-stroke alpha constant property.
+     *
+     * @return The value of the non-stroke alpha constant parameter.
+     */
+    public double getNonStrokeAlphaConstant()
+    {
+        return nonStrokingAlphaConstant;
+    }
+
+    /**
+     * set the value of the non-stroke alpha constant property.
+     *
+     * @param value The value of the non-stroke alpha constant parameter.
+     */
+    public void setNonStrokeAlphaConstant(double value)
+    {
+        nonStrokingAlphaConstant = value;
+    }
 
     /**
      * get the value of the stroke alpha source property.
@@ -200,9 +200,9 @@ public class PDGraphicsState implements
 
     /**
-     * Get the value of the stroke alpha constants property.
+     * Get the value of the stroke alpha constant property.
      *
@@ -200,9 +200,9 @@ public class PDGraphicsState implements
      *
-     * @return The value of the stroke alpha constants parameter.
+     * @return The value of the stroke alpha constant parameter.
      */
     public double getAlphaConstant()
@@ -210,9 +210,9 @@ public class PDGraphicsState implements
 
     /**
-     * set the value of the stroke alpha constants property.
+     * set the value of the stroke alpha constant property.
      *
@@ -210,9 +210,9 @@ public class PDGraphicsState implements
      *
-     * @param value The value of the stroke alpha constants parameter.
+     * @param value The value of the stroke alpha constant parameter.
      */
     public void setAlphaConstant(double value)
@@ -220,24 +220,48 @@ public class PDGraphicsState implements
 
     /**
-     * Get the value of the non-stroke alpha constants property.
+     * Get the value of the non-stroke alpha constant property.
      *
@@ -220,24 +220,48 @@ public class PDGraphicsState implements
      *
-     * @return The value of the non-stroke alpha constants parameter.
+     * @return The value of the non-stroke alpha constant parameter.
+     * @deprecated use {@link #getNonStrokeAlphaConstant() }
      */
@@ -220,24 +220,48 @@ public class PDGraphicsState implements
 
     /**
-     * set the value of the non-stroke alpha constants property.
+     * set the value of the non-stroke alpha constant property.
      *
@@ -220,24 +220,48 @@ public class PDGraphicsState implements
      *
-     * @param value The value of the non-stroke alpha constants parameter.
+     * @param value The value of the non-stroke alpha constant parameter.
+     * @deprecated use {@link #setNonStrokeAlphaConstant(double) }
      */